# package information.
INFO = dict(
    name="Mew Calc",
    description="The calculator fot cat's age",
    author="shinriyo",
    author_email="shinriyo@gmail.com",
    license="MIT License",
    url="https://github.com/shinriyo/cat_age_calculator",
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "License :: OSI Approved :: MIT License"
    ]
)

from .port_killer import nothing
