# package information.
INFO = dict(
  name        = "port_killer",
  description = "It kills process by specify port number.",
  author      = "shinriyo",
  author_email = "shinriyo@gmail.com",
  license     = "MIT License",
  url         = "https://github.com/shinriyo/port_killer",
  classifiers = [
    "Programming Language :: Python :: 2.7",
    "License :: OSI Approved :: MIT License"
  ]
)
