#!/usr/bin/env python
# -*- coding: utf-8 -*-

import random
import unittest
from lib.port_killer.port_killer import nothing

from datetime import datetime, date, time


class PortKillerTest(unittest.TestCase):
    def setUp(self):
        pass

    def test_port(self):
        """
        """
        self.assertEqual(True, True)


if __name__ == '__main__':
    unittest.main()
